@@ -17,7 +17,7 @@ class Publisher(object):
     def __init__(self, topic_id):
         self.instance = pubsub_v1.PublisherClient()
         self.topic_name = 'projects/{project_id}/topics/{topic}'.format(
-            project_id=os.getenv('PUBSUB_PROJECT_ID'),
+            project_id=os.getenv('PUBSUB_PUBLISHER_PROJECT_ID'),
             topic=topic_id,
         )
 
